@@ -24,7 +24,7 @@ class Admin(Vault):
         using vault creds.  Don't do this on redeploy!
         """
         if self.config:
-            text = None
+            text = ""
             while text.lower() not in ["y", "n"]:
                 text = input("Server already exists in config.  Some values may be overwritten.  Continue? (y/n)")
     
