@@ -1,4 +1,4 @@
-from gevault.vault import Vault
+from gevault.lib.vault import Vault
 
 def test_update_config():
     Vault.update_config("testKey", "testValue")
